{% extends "page.html" %}

{% block main %}

<div class="container">
    <div class="row">
      <div class="swan-info">
        <div id="swan-loader">
          <div class="loader-circle">
            <img src="{{ static_url('swan/logos/' + swan_logo_filename) }}">
          </div>
          <span class="text">{% block heading %}{% if failed %}Spawn failed{% else %}Server not running{% endif %}{% endblock %}
            <p class="extra">
                {% block message %}
                {% if failed %}
                    The latest attempt to start your server {{ server_name }} has failed.
                    {% if failed_html_message %}
                      </p><p>{{ failed_html_message | safe }}</p><p>
                    {% elif failed_message %}
                      </p><p>{{ failed_message }}</p><p>
                    {% endif %}
                {% else %}
                    Your server {{ server_name }} is not running. 
                {% endif %}
                {% endblock %}
                {% block start_button %}
                <a id="start" role="button" href="{{ spawn_url }}">
                    Click here to 
                    {% if failed %}
                    try again. 
                    {% else %}
                    start a new session. 
                    {% endif %}
                </a>
            {% endblock %}
            </p>
          </span>
        </div>
      </div>
    </div>
  </div>

{% endblock %}