/* Fonts */

@font_family_1: 'Roboto', sans-serif;

/* Sizes */

@size-1: 28px;
@size-2: 20px;
@size-3: 18px;
@size-4: 16px;
@size-5: 14px;
@size-6: 13px;
@size-7: 12px;
@size-8: 11px;

@loader-size: 450px;

@modal-width: 450px;
@modal-width-large: 650px;
@modal-padding: 20px;

/* Colors */

@color-primary: #0053A1;
@color-primary-dark: #03263C;
@color-primary-light: #3399FF;
@color-secondary: #FF6600;

@button-green: #698c00;
@button-red: #ac0909;
@button-blue: @color-primary;
@button-normal: @grey-5;
@button-yellow: #f09a47;

@grey-1: #FAFAFA;
@grey-2: #EEEEEE;
@grey-3: #DADADA;
@grey-4: #DDDDDD;
@grey-5: #B9B9B9;
@grey-6: #777777;
@grey-7: #505050;
@black: #262626;

/* Header */

@header-height: 70px;
@header-border: 1px;
@menu-border-size: 3px;
@menu-font-size: @size-3;

@header-background: @color-primary-dark;
@menu-color: @grey-3;

/* Footer */

@footer-height: 85px;

@footer-background: @grey-1;
@footer-border: @grey-3;
