@charset "UTF-8";

@font-face {
    font-family: "swan-icons";
    src: url("fonts/swan-icons.eot");
    src: url("fonts/swan-icons.eot?#iefix") format("embedded-opentype"),
    url("fonts/swan-icons.woff") format("woff"),
    url("fonts/swan-icons.ttf") format("truetype"),
    url("fonts/swan-icons.svg#swan-icons") format("svg");
    font-weight: normal;
    font-style: normal;
}

[class^="icon-"]:before {
    font-family: "swan-icons" !important;
    font-style: normal !important;
    font-weight: normal !important;
    font-variant: normal !important;
    text-transform: none !important;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

.icon-streamline-sync:before {
    content: "\75";
}

.icon-icon-folder-close:before,
.project_icon:before {
    font-family: "swan-icons" !important;
    content: "\79" !important;
    vertical-align: middle;
    font-style: normal;
}

.icon-expand:before {
    content: "\74";
    vertical-align: text-top;
}

.icon-angle-right:before {
    content: "\41";
}

.icon-fa-times:before {
    content: "\42";
}

.icon-fa-plus:before {
    content: "\43";
}

.icon-folder-icon:before,
.folder_icon:before {
    font-family: "swan-icons" !important;
    content: "\48" !important;
    vertical-align: middle;
}

.icon-user:before {
    content: "\4d";
}

.icon-users:before {
    content: "\4e";
}

.icon-cernbox-abstract:before {
    content: "\62";
    font-size: 17px;
    line-height: 15px;
    vertical-align: top;
}

.icon-multiply:before {
    content: "\63";
}

.icon-more:before {
    content: "\65";
}

.icon-up:before {
    content: "\66";
}

.icon-collapse:before {
    content: "\61";
}

.icon-arrow-left:before {
    content: "\64";
}

.icon-home:before {
    content: "\67";
}

.icon-clockwise:before {
    content: "\68";
    vertical-align: middle;
}
.icon-clone:before {
  content: "\69";
}
.icon-checked:before {
  content: "\6a";
}
