{% extends "error.html" %}

{% block h1_error %}
<h1>Maintenance mode</h1>
{% endblock %}

{% block error_detail %}
<p>This machine is scheduled for maintenance.<br>Please, always use <a href="https://swan.cern.ch">swan.cern.ch</a> instead of going directly to a specific machine.</p>
{% endblock %}

