{% extends "page.html" %}

{% block login_widget %}
{% endblock %}

{% block main %}

{% block login %}
<div class="container">
  <div class="row">
    <div class="swan-info">
      <div id="swan-loader">
        <div class="loader-circle">
          <img src="{{ static_url('swan/logos/' + swan_logo_filename) }}">
        </div>
        <div class="loader-line-mask">
          <div class="loader-line"></div>
        </div>
        <span class="text">Logging you in</span>
      </div>
    </div>
  </div>
</div>
{% endblock login %}

{% endblock %}

{% block script %}
{{super()}}
<script type="text/javascript">
  window.location.replace('{{authenticator_login_url}}');
</script>
{% endblock %}
