{% extends "page.html" %}

{% block main %}

<div class="container">
  <div class="row">
    <div class="swan-info">
      <div id="swan-loader">
        <div class="loader-circle">
          <img src="{{ static_url('swan/logos/' + swan_logo_filename) }}">
        </div>
        <div class="loader-line-mask">
          <div class="loader-line"></div>
        </div>
        <span class="text">Stopping your session
          <p class="extra">You will be able to start it again once it has finished stopping.<br>
            If this is taking too long, <a id="refresh" href="#">click here to refresh</a>.</p>
        </span>
      </div>
    </div>
  </div>
</div>

{% endblock %}

{% block script %}
{{ super() }}
<script type="text/javascript">
require(["jquery"], function ($) {
  $("#refresh").click(function () {
    window.location.reload();
  });
  setTimeout(function () {
    window.location.reload();
  }, 5000);
});
</script>
{% endblock %}